no longer overwrite guest's /etc/yum.conf with the version from the host
[vserver-reference.git] / build.sh
index cbb1f89..28e23c3 100755 (executable)
--- a/build.sh
+++ b/build.sh
@@ -56,24 +56,26 @@ vrefname=default
 vref=${vrefdir}/${vrefname}
 install -d -m 755 ${vref}
 
-# "Parse" out the packages and groups for mkfedora
-lst="${pldistro}-vserver.lst"
-options="$(pl_getPackagesOptions2 ${pl_DISTRO_NAME} $lst) $(pl_getGroupsOptions ${pl_DISTRO_NAME} $lst)"
+# locate the packages and groups file
+pkgsfile=$(pl_locateDistroFile ../build/ ${pldistro} vserver.pkgs)
 
-# Populate a minimal /dev in the reference image
-pl_makedevs ${vref}
+# Some of the PlanetLab RPMs attempt to (re)start themselves in %post,
+# unless the installation is running inside the BootCD environment. We
+# would like to pretend that we are.
+export PL_BOOTCD=1
 
 # Populate image with vserver-reference packages
-pl_setup_chroot ${vref} ${options} -k
+pl_root_setup_chroot ${vref} -k -f $pkgsfile
 
-for systemvserver in ${pldistro}-vservers/*.lst ; do
-    NAME=$(basename $systemvserver .lst)
+systemvserver_count=$(ls ../build/config.${pldistro}/vserver-*.pkgs 2> /dev/null | wc -l)
+[ $systemvserver_count -gt 0 ] && for systemvserver in $(ls ../build/config.${pldistro}/vserver-*.pkgs) ; do
+    NAME=$(basename $systemvserver .pkgs | sed -e s,vserver-,,)
 
     echo "--------START BUILDING system vserver ${NAME}: $(date)"
 
     # "Parse" out the packages and groups for yum
-    systempackages=$(pl_getPackages $systemvserver)
-    systemgroups=$(pl_getGroups $systemvserver)
+    systempackages=$(pl_getPackages ${pl_DISTRO_NAME} $systemvserver)
+    systemgroups=$(pl_getGroups ${pl_DISTRO_NAME} $systemvserver)
 
     vdir=${vstubdir}/${NAME}
     rm -rf ${vdir}/*
@@ -90,6 +92,11 @@ for systemvserver in ${pldistro}-vservers/*.lst ; do
     [ -n "$systempackages" ] && yum -c ${vdir}/etc/yum.conf --installroot=${vdir} -y install $systempackages
     [ -n "$systemgroups" ] && yum -c ${vdir}/etc/yum.conf --installroot=${vdir} -y groupinstall $systemgroups
 
+       pkgsdir=$(dirname $pkgsfile)
+       pkgsname=$(basename $pkgsfile .pkgs)
+       postfile="${pkgsdir}/${pkgsname}.post"
+       [ -f $postfile ] && /bin/bash $postfile ${vdir} || :
+
     # Create a copy of the system vserver w/o the vserver reference files and make it smaller. 
     # This is a three step process: